@@ -205,10 +205,10 @@ class Connection():
 
 
     def __is_join__(self, table_name):
-        return tb_name in self._join or tb_name in self._inner
+        return table_name in self._join or table_name in self._inner
 
     def __is_include__(self, table_name):
-        return tb_name in self._include
+        return table_name in self._include
 
     def __is__main_select__(self, field):
         if not '.' in field:
