@@ -18,9 +18,9 @@ def main(arg):
 
     conn = bravaorm.Connection(db_user="root", db_password="1234", db_host="127.0.0.1", db_port=3306, db_database="gofans", db_charset="utf8mb4", log_level='debug')
 
-    usuario = conn.usuarios.join("postagens").where("id = 46, postagens.id>0").first
+    usuariosDirect = conn.directs_usuarios.inner("websockets").where("id_usuario!=47, id_direct=1").all
 
-    print(usuario.fans)
+    print(usuariosDirect.toJSON())
 
     conn.close()
 
